RTPI - Oxfordshire

Oxontime Links

- Oxontime Home
- Search Options
- News / Status
- SMS Service
- About Oxontime
- Coverage
- Instructions / Help
- Terms of Use
- Text Only

Contact Us

- contact@oxontime.com
Oxontime RTI
Oxfordshire County Council
Speedwell House
Speedwell Street
Oxford OX1 1NE

# Search options

To find live departure information on bus services use the search options below and select your required bus stop.

﻿

| SMS number | Stop name | Town/Village
--- | --- | --- | ---
+ | 69326572 | View on map | Magdalen Street Stop C3 | Oxford City Centre
| 69323858 | View on map | Radcliffe Infirmary | Woodstock Road
| 69323839 | View on map | Plantation Road | Woodstock Road
| 69323756 | View on map | Canterbury Road | Woodstock Road
| 69323758 | View on map | St Margaret's Road | Woodstock Road
| 69323762 | View on map | Lathbury Road | Woodstock Road
| 69323764 | View on map | Beechcroft Road | Woodstock Road
+ | 69323767 | View on map | South Parade | Woodstock Road
| 69323823 | View on map | Osberton Road | Woodstock Road
| 69323754 | View on map | Squitchey Lane | Woodstock Road
| 69323785 | View on map | Woodstock Close | Woodstock Road
| 69323787 | View on map | First Turn | Woodstock Road
+ | 69323852 | View on map | Wolvercote School | Upper Wolvercote
| 69346858 | View on map | Millway Close | Upper Wolvercote
| 69342892 | View on map | Goose Green Close | Upper Wolvercote
| 69323846 | View on map | Elmthorpe Road | Lower Wolvercote
| 69323824 | View on map | Rosamund Road | Lower Wolvercote
+ | 69323847 | View on map | Home Close Terminus | Lower Wolvercote

Expand All